
/*     *******************************************************************************
	XVisual GUI Development System for Linux/X-Window
	Copyright (C) 1996 Steve Carrie.

        This program is free software; you can redistribute it and/or modify
        it under the terms of the GNU General Public License as published by
        the Free Software Foundation; either version 2 of the License, or
        (at your option) any later version.

        This program is distributed in the hope that it will be useful,
        but WITHOUT ANY WARRANTY; without even the implied warranty of
        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
        GNU General Public License for more details.

        You should have received a copy of the GNU General Public License
        along with this program; if not, write to the Free Software
        Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
        ******************************************************************************* */

#include <X11/Intrinsic.h>
#include <X11/StringDefs.h>
#include <X11/Xaw3d/Scrollbar.h>
#include <X11/xv/xvCore.h>
#include <X11/xv/xvScrollbar.h>


// ------------------------------------------

xvScrollbar::xvScrollbar()
{
	alloc=FALSE;
}

// ------------------------------------------

xvScrollbar::xvScrollbar(String name, xvCore & parent, XtOrientation orient, Dimension sizeL, 
		XtCallbackProc scrollProc, XtCallbackProc thumbProc, XtCallbackProc jumpProc)
{
	init(name, parent, orient, sizeL, scrollProc, thumbProc, jumpProc);
}

// ------------------------------------------

xvScrollbar::~xvScrollbar()
{
	if (alloc) XtDestroyWidget(w);
}

// ------------------------------------------

void xvScrollbar::init(String name, xvCore & parent, XtOrientation orient, Dimension sizeL,
		XtCallbackProc scrollProc, XtCallbackProc thumbProc, XtCallbackProc jumpProc)
{
	w=XtVaCreateManagedWidget(name, scrollbarWidgetClass, parent.ID(), 
		"orientation", orient,
		"length", sizeL,
		NULL);

	XtAddCallback(w, XtNscrollProc, scrollProc, 0);
	XtAddCallback(w, XtNthumbProc, thumbProc, 0);
	XtAddCallback(w, XtNjumpProc, jumpProc, 0);
	alloc=TRUE;
}

// -------------------------------------------

void xvScrollbar::SetThumb(float t_pos, float t_size)
{
	if (sizeof(float) > sizeof(XtArgVal)) {
		XtVaSetValues(w, XtNtopOfThumb, (XtArgVal) t_pos, NULL);
		XtVaSetValues(w, XtNshown, (XtArgVal) t_size, NULL);
	}
	else {
		XtArgVal * l_pos = (XtArgVal *) &t_pos;
		XtArgVal * l_size = (XtArgVal *) &t_size;
		XtVaSetValues(w, XtNtopOfThumb, *l_pos, NULL);
		XtVaSetValues(w, XtNshown, *l_size, NULL);
	}		
}

// ------------------------------------------